Client

Struct Client 

pub struct Client { /* private fields */ }
OpenCode client for interacting with the server.

Implementations

Source

impl Client

pub fn builder() -> ClientBuilder

Create a new client builder.

pub fn sessions(&self) -> SessionsApi

Get the sessions API.

pub fn messages(&self) -> MessagesApi

Get the messages API.

pub fn parts(&self) -> PartsApi

Get the parts API.

pub fn permissions(&self) -> PermissionsApi

Get the permissions API.

pub fn files(&self) -> FilesApi

Get the files API.

pub fn find(&self) -> FindApi

Get the find API.

pub fn providers(&self) -> ProvidersApi

Get the providers API.

pub fn mcp(&self) -> McpApi

Get the MCP API.

pub fn pty(&self) -> PtyApi

Get the PTY API.

pub fn config(&self) -> ConfigApi

Get the config API.

pub fn tools(&self) -> ToolsApi

Get the tools API.

pub fn project(&self) -> ProjectApi

Get the project API.

pub fn worktree(&self) -> WorktreeApi

Get the worktree API.

pub fn sync(&self) -> SyncApi

Get the sync API.

pub fn tui(&self) -> TuiApi

Get the TUI API.

pub fn workspaces(&self) -> WorkspacesApi

Get the workspaces API.

pub fn console(&self) -> ConsoleApi

Get the console API.

pub fn experimental_session(&self) -> ExperimentalSessionApi

Get the experimental session API.

pub fn misc(&self) -> MiscApi

Get the misc API.

pub fn question(&self) -> QuestionApi

Get the question API.

pub fn skills(&self) -> SkillsApi

Get the skills API.

pub fn resource(&self) -> ResourceApi

Get the resource API (experimental).

pub fn global(&self) -> GlobalApi

Get the global API for event stream metadata and health checks.

pub async fn run_simple_text(&self, text: impl Into<String>) -> Result<Session>

Simple helper to create session and send a text prompt.

Note: This method returns immediately after sending the prompt. The AI response will arrive asynchronously via SSE events. Use [subscribe_session] to receive the response.

Errors

Returns an error if session creation or prompt fails.

Source

impl Client

pub fn sse_subscriber(&self) -> SseSubscriber

Get an SSE subscriber for streaming events.

pub fn subscribe(&self) -> Result<SseSubscription<Event>>

Subscribe to all events for the configured directory with default options.

This subscribes to the /event endpoint which streams all events for the directory specified in the client configuration.

Errors

Returns an error if the subscription cannot be created.

pub fn subscribe_session( &self, session_id: &str, ) -> Result<SseSubscription<Event>>

Subscribe to events filtered by session ID with default options.

Events are filtered client-side to only include events matching the specified session ID.

Errors

Returns an error if the subscription cannot be created.

pub fn subscribe_global(&self) -> Result<SseSubscription<GlobalEvent>>

Subscribe to global events with default options (all directories).

Errors

Returns an error if the subscription cannot be created.